@@ -39,6 +39,7 @@ except Exception:
     scan_subtypes['Scan2D'].pop(scan_subtypes['Scan2D'].index('Adaptive'))
     scan_subtypes['Tabular'].pop(scan_subtypes['Tabular'].index('Adaptive'))
     adaptive_losses = None
+    adaptive = None
     logger.info('adaptive module is not present, no adaptive scan possible')
 
 
@@ -245,11 +246,12 @@ class ScanParameters:
 
     def evaluate_Nsteps(self):
         Nsteps = 1
-        for ind in range(len(self.starts)):
-            if self.scan_subtype != 'Spiral':
-                Nsteps *= np.abs((self.stops[ind] - self.starts[ind]) / self.steps[ind])+1
-            else:
-                Nsteps *= np.abs(2 * (self.stops[ind] / self.steps[ind]) + 1)
+        if self.starts is not None:
+            for ind in range(len(self.starts)):
+                if self.scan_subtype != 'Spiral':
+                    Nsteps *= np.abs((self.stops[ind] - self.starts[ind]) / self.steps[ind])+1
+                else:
+                    Nsteps *= np.abs(2 * (self.stops[ind] / self.steps[ind]) + 1)
         return Nsteps
 
     def __repr__(self):
@@ -908,6 +910,8 @@ class TableModelTabular(gutils.TableModel):
                 self.remove_row(0)
 
             data = np.loadtxt(fname)
+            if len(data.shape) == 1:
+                data = data.reshape((data.size, 1))
             self.set_data_all(data)
 
     def save_txt(self):
